@@ -160,7 +160,7 @@ subsetList <- function(data, list){
 #' The purpose is to properly derive data for the average observation in the
 #' data by being 'aware' of formulas that contain interactions and/or function
 #' calls. For example, in the old behavior, if the formula contained a square
-#' term specified as \code{I(x^2)}, we were returning the mean of x{^2} not the
+#' term specified as \code{I(x^2)}, we were returning the mean of \code{x(^2)} not the
 #' square of mean(x).
 #'
 #' @param merMod the merMod object from which to draw the average observation
@@ -435,7 +435,7 @@ REquantile <- function(merMod, quantile, groupFctr, term = "(Intercept)"){
     stop("Random effect group name not found. Please respecify grouping factor.")
   }
   myRE.tmp <- try(myRE[order(myRE[, term]), ,drop = FALSE], silent = TRUE)
-  if(class(myRE.tmp) != "data.frame"){
+  if(!is(myRE.tmp, "data.frame")){
     term1 <- names(myRE)[1]
     myRE.tmp <- try(myRE[order(myRE[, term1]), ,drop = FALSE], silent = TRUE)
     warning(paste0(term, " not found in random effect terms. Returning first term, ",
